import { WorkspaceConfiguration } from './types/config.js';
import type { WorkspaceManifests } from './types/workspace.js';
import type { PackageJson } from 'type-fest';
export default class DependencyDeputy {
    _manifests: WorkspaceManifests;
    manifests: Map<string, PackageJson>;
    canceledWorkspaces: Set<string>;
    referencedDependencies: Map<string, Set<string>>;
    peerDependencies: Map<string, Map<string, Set<string>>>;
    tsConfigPathGlobs: Map<string, string[]>;
    isProduction: boolean;
    constructor();
    addWorkspace({ name, dir, manifestPath, manifest, isProduction, }: {
        name: string;
        dir: string;
        manifestPath: string;
        manifest: PackageJson;
        isProduction: boolean;
    }): void;
    cancelWorkspace(workspaceName: string): void;
    getManifest(workspaceName: string): PackageJson | undefined;
    getWorkspaceManifest(workspaceName: string): {
        workspaceDir: string;
        manifestPath: string;
        scripts: string[];
        dependencies: string[];
        peerDependencies: string[];
        optionalDependencies: string[];
        devDependencies: string[];
        productionDependencies: string[];
        allDependencies: string[];
    } | undefined;
    getProductionDependencies(workspaceName: string): string[];
    getDevDependencies(workspaceName: string): string[];
    getAllDependencies(workspaceName: string): string[];
    addTypeScriptConfigPathGlobs(workspaceName: string, paths: Record<string, string[]>): void;
    addReferencedDependency(workspaceName: string, packageName: string): void;
    addPeerDependencies(workspaceName: string, peerDependencies: Map<string, Set<string>>): void;
    maybeAddListedReferencedDependency(workspace: {
        name: string;
        dir: string;
        config: WorkspaceConfiguration;
        ancestors: string[];
    }, moduleSpecifier: string, isStrict: boolean): string | undefined;
    isInternalDependency(workspaceName: string, moduleSpecifier: string): boolean | undefined;
    private isAliasedDependency;
    resolvePackageName(moduleSpecifier: string): string;
    private isInDependencies;
    settleDependencyIssues(): {
        dependencyIssues: {
            filePath: string;
            symbol: string;
        }[];
        devDependencyIssues: {
            filePath: string;
            symbol: string;
        }[];
    };
}
