import { compact } from '../util/array.js';
import { IGNORED_GLOBAL_BINARIES } from '../util/constants.js';
import { timerify } from '../util/performance.js';
import { getBinariesFromScripts, getPackageManifest } from './helpers.js';
const findManifestDependencies = async (ignoreBinaries, manifest, isRoot, dir, cwd) => {
    const referencedDependencies = new Set();
    const peerDependencies = new Map();
    const scripts = compact(Object.values(manifest.scripts ?? {}));
    const referencedBinaries = getBinariesFromScripts(scripts)
        .filter(binaryName => !IGNORED_GLOBAL_BINARIES.includes(binaryName))
        .filter(binaryName => !ignoreBinaries.includes(binaryName));
    const installedBinaries = new Map();
    const deps = [...Object.keys(manifest.dependencies ?? {}), ...Object.keys(manifest.devDependencies ?? {})];
    for (const packageName of deps) {
        const manifest = await getPackageManifest(dir, packageName, isRoot, cwd);
        if (manifest) {
            const binaries = typeof manifest.bin === 'string' ? [packageName] : Object.keys(manifest.bin ?? {});
            binaries.forEach(binaryName => installedBinaries.set(binaryName, packageName));
            const packagePeerDependencies = Object.keys(manifest.peerDependencies ?? {});
            packagePeerDependencies.forEach(packagePeerDependency => {
                if (peerDependencies.has(packagePeerDependency)) {
                    peerDependencies.get(packagePeerDependency)?.add(packageName);
                }
                else {
                    peerDependencies.set(packagePeerDependency, new Set([packageName]));
                }
            });
        }
    }
    for (const binaryName of referencedBinaries) {
        const packageName = installedBinaries.get(binaryName);
        referencedDependencies.add(packageName ?? binaryName);
    }
    return {
        dependencies: Array.from(referencedDependencies),
        peerDependencies,
    };
};
export const findDependencies = timerify(findManifestDependencies);
