import { compact } from '../../util/array.js';
import load from '../../util/loader.js';
import { timerify } from '../../util/performance.js';
import { resolvePresetName, resolvePluginName } from './helpers.js';
export const CONFIG_FILE_PATTERNS = [
    'babel.config.json',
    'babel.config.js',
    '.babelrc.json',
    '.babelrc.js',
    '.babelrc',
    'package.json',
];
export const isEnabled = ({ dependencies }) => {
    return (dependencies.has('@babel/cli') ||
        dependencies.has('@babel/core') ||
        dependencies.has('@babel/preset-env') ||
        dependencies.has('@babel/register'));
};
const api = {
    caller: () => true,
};
const getDependenciesFromConfig = (config) => {
    if (config) {
        const presets = config.presets?.map(preset => (typeof preset === 'string' ? preset : preset[0])).map(resolvePresetName) ?? [];
        const plugins = config.plugins?.map(plugin => (typeof plugin === 'string' ? plugin : plugin[0])).map(resolvePluginName) ?? [];
        return compact([...presets, ...plugins]);
    }
    return [];
};
const findBabelDependencies = async (configFilePath, { manifest }) => {
    if (configFilePath.endsWith('package.json')) {
        const config = manifest?.babel;
        return getDependenciesFromConfig(config);
    }
    let config = await load(configFilePath);
    if (typeof config === 'function') {
        config = config(api);
    }
    return getDependenciesFromConfig(config);
};
export const findDependencies = timerify(findBabelDependencies);
