import path from 'node:path';
import { ESLint } from 'eslint';
import { compact } from '../../util/array.js';
import { getPackageName } from '../../util/modules.js';
import { timerify } from '../../util/performance.js';
import { getDependenciesFromSettings } from './helpers.js';
export const isEnabled = ({ dependencies }) => {
    return dependencies.has('eslint');
};
export const CONFIG_FILE_PATTERNS = ['eslint.config.js', '.eslintrc', '.eslintrc.json', '.eslintrc.js'];
const resolvePluginPackageName = (pluginName) => {
    return pluginName.startsWith('@')
        ? pluginName.includes('/')
            ? pluginName
            : `${pluginName}/eslint-plugin`
        : `eslint-plugin-${pluginName}`;
};
const findESLintDependencies = async (configFilePath, { cwd }) => {
    if (path.basename(configFilePath) === 'eslint.config.js') {
        return [];
    }
    else {
        const engine = new ESLint({ cwd, overrideConfigFile: configFilePath, useEslintrc: false });
        const jsConfig = await engine.calculateConfigForFile('__placeholder__.js');
        const tsConfig = await engine.calculateConfigForFile('__placeholder__.ts');
        const tsxConfig = await engine.calculateConfigForFile('__placeholder__.spec.tsx');
        const dependencies = [jsConfig, tsConfig, tsxConfig].map(config => {
            if (!config)
                return [];
            const plugins = config.plugins?.map(resolvePluginPackageName) ?? [];
            const parsers = config.parser ? [config.parser] : [];
            const extraParsers = config.parserOptions?.babelOptions?.presets ?? [];
            const settings = config.settings ? getDependenciesFromSettings(config.settings) : [];
            return [...parsers, ...extraParsers, ...plugins, ...settings].map(getPackageName);
        });
        return compact(dependencies.flat());
    }
};
export const findDependencies = timerify(findESLintDependencies);
