import path from 'node:path';
import { globby } from 'globby';
import { compact } from './array.js';
import { debugLogObject } from './debug.js';
import { timerify } from './performance.js';
const ensurePosixPath = (value) => value.split(path.sep).join(path.posix.sep);
const prependDirToPattern = (workingDir, pattern) => {
    if (pattern.startsWith('!'))
        return '!' + path.posix.join(workingDir, pattern.slice(1));
    return path.posix.join(workingDir, pattern);
};
export const negate = (pattern) => `!${pattern}`;
const sortNegatedLast = (a, b) => (a.startsWith('!') ? 1 : b.startsWith('!') ? -1 : 0);
const glob = async ({ cwd, workingDir = cwd, patterns, ignore = [], gitignore = true, }) => {
    const cwdPosix = ensurePosixPath(cwd);
    const workingDirPosix = ensurePosixPath(workingDir);
    const relativePath = path.posix.relative(cwdPosix, workingDirPosix);
    const prepend = (pattern) => prependDirToPattern(relativePath, pattern);
    const globPatterns = compact([patterns].flat().map(prepend)).sort(sortNegatedLast);
    const ignorePatterns = [...ignore, '**/node_modules/**'];
    debugLogObject(2, "Globbin'", { cwd, globPatterns, ignorePatterns });
    return globby(globPatterns, {
        cwd,
        ignore: ignorePatterns,
        gitignore,
        absolute: true,
        dot: true,
    });
};
const pureGlob = async ({ cwd, patterns, ignore }) => globby(patterns, {
    cwd,
    ignore: [...ignore, '**/node_modules/**'],
    absolute: true,
});
const dirGlob = async ({ cwd, patterns, ignore }) => globby(patterns, {
    cwd,
    ignore: [...ignore, '**/node_modules/**'],
    expandDirectories: false,
    onlyDirectories: true,
});
export const _glob = timerify(glob);
export const _pureGlob = timerify(pureGlob);
export const _dirGlob = timerify(dirGlob);
