import type { Configuration, PluginConfiguration, PluginName, WorkspaceConfiguration } from './types/config.js';
import type { Issue } from './types/issues.js';
import type { PackageJson } from 'type-fest';
type WorkspaceManagerOptions = {
    name: string;
    dir: string;
    config: WorkspaceConfiguration;
    manifest: PackageJson;
    ancestorManifests: PackageJson[];
    rootWorkspaceConfig: WorkspaceConfiguration;
    rootConfig: Configuration;
    negatedWorkspacePatterns: string[];
    rootManifest: PackageJson;
    rootWorkspaceDir: string;
};
type ReferencedDependencyIssues = Set<Issue>;
type ReferencedDependencies = Set<string>;
export default class WorkspaceWorker {
    name: string;
    dir: string;
    config: WorkspaceConfiguration;
    ancestorManifests: PackageJson[];
    rootWorkspaceConfig: WorkspaceConfiguration;
    rootConfig: Configuration;
    referencedDependencyIssues: ReferencedDependencyIssues;
    manifest: PackageJson;
    rootWorkspaceDir: string;
    referencedDependencies: ReferencedDependencies;
    peerDependencies: Map<string, Set<string>>;
    negatedWorkspacePatterns: string[];
    enabled: {
        babel: boolean;
        capacitor: boolean;
        changesets: boolean;
        cypress: boolean;
        eslint: boolean;
        gatsby: boolean;
        jest: boolean;
        next: boolean;
        nx: boolean;
        playwright: boolean;
        postcss: boolean;
        remark: boolean;
        remix: boolean;
        rollup: boolean;
        storybook: boolean;
    };
    isRoot: boolean;
    constructor({ name, dir, config, ancestorManifests, rootWorkspaceConfig, rootConfig, negatedWorkspacePatterns, manifest, rootWorkspaceDir, }: WorkspaceManagerOptions);
    getConfigForPlugin(pluginName: PluginName): PluginConfiguration;
    init(): Promise<void>;
    setEnabledPlugins(): void;
    initReferencedDependencies(): Promise<void>;
    getEntryFilePatterns(): string[];
    getProjectFilePatterns(): string[];
    getPluginEntryFilePatterns(isProduction?: boolean): string[];
    getPluginProjectFilePatterns(): string[];
    getPluginConfigPatterns(): string[];
    getProductionEntryFilePatterns(): string[];
    getProductionProjectFilePatterns(): string[];
    getProductionPluginEntryFilePatterns(): string[];
    getConfigurationEntryFilePattern(pluginName: PluginName): string[];
    getWorkspaceIgnorePatterns(): string[];
    findDependenciesByPlugins(): Promise<{
        referencedDependencyIssues: ReferencedDependencyIssues;
        referencedDependencies: ReferencedDependencies;
    }>;
    private findDependenciesByPlugin;
}
export {};
